@@ -66,6 +66,304 @@ mod doublepq_tests {
         assert_eq!(pq.len(), 3);
     }
 
+    #[test]
+    fn contains() {
+        let mut pq = DoublePriorityQueue::new();
+        assert!(!pq.contains("a"));
+        pq.push("a", 1);
+        pq.push("b", 2);
+        pq.push("f", 7);
+        pq.push("g", 5);
+        pq.push("h", 3);
+
+        assert!(pq.contains("f"));
+
+        pq.pop_max();
+
+        assert!(!pq.contains("f"));
+    }
+
+    #[test]
+    fn pop_if() {
+        let mut pq = DoublePriorityQueue::new();
+        assert_eq!(pq.pop_min_if(|_, _| true), None);
+        assert_eq!(pq.pop_max_if(|_, _| true), None);
+        pq.push("a", 1);
+        pq.push("b", 2);
+        pq.push("f", 7);
+        pq.push("g", 4);
+        pq.push("h", 3);
+        println!("{:?}", pq);
+        assert_eq!(pq.pop_min_if(|_, _| false), None);
+        assert_eq!(pq.pop_max_if(|_, _| false), None);
+        println!("{:?}", pq);
+
+        assert_eq!(
+            pq.pop_min_if(|_, p| {
+                *p = 10;
+                true
+            }),
+            Some(("a", 10))
+        );
+        assert_eq!(
+            pq.pop_max_if(|_, p| {
+                *p = 10;
+                true
+            }),
+            Some(("f", 10))
+        );
+        println!("{:?}", pq);
+
+        assert_eq!(
+            pq.pop_min_if(|_, p| {
+                *p = 10;
+                false
+            }),
+            None
+        );
+        println!("{:?}", pq);
+        assert_eq!(pq.peek_min(), Some((&"h", &3)));
+        assert_eq!(pq.peek_max(), Some((&"b", &10)));
+        println!("{:?}", pq);
+        assert_eq!(
+            pq.pop_max_if(|_, p| {
+                *p = 2;
+                false
+            }),
+            None
+        );
+        assert_eq!(pq.peek_min(), Some((&"b", &2)));
+        assert_eq!(pq.peek_max(), Some((&"g", &4)));
+        println!("{:?}", pq);
+    }
+
+    #[test]
+    fn peek_mut() {
+        use std::hash::{Hash, Hasher};
+
+        #[derive(Debug)]
+        struct Person {
+            id: u32,
+            name: String,
+            phone: u64,
+        }
+
+        impl Hash for Person {
+            fn hash<H: Hasher>(&self, state: &mut H) {
+                self.id.hash(state);
+                self.phone.hash(state);
+            }
+        }
+
+        impl PartialEq for Person {
+            fn eq(&self, other: &Self) -> bool {
+                self.id == other.id && self.phone == other.phone
+            }
+        }
+
+        impl Eq for Person {}
+
+        let mut pq = DoublePriorityQueue::new();
+        assert_eq!(pq.peek_max_mut(), None);
+        assert_eq!(pq.peek_min_mut(), None);
+        pq.push(
+            Person {
+                id: 1,
+                name: "a".to_string(),
+                phone: 39281048279,
+            },
+            1,
+        );
+        pq.push(
+            Person {
+                id: 2,
+                name: "b".to_string(),
+                phone: 23912750234,
+            },
+            2,
+        );
+        pq.push(
+            Person {
+                id: 3,
+                name: "c".to_string(),
+                phone: 1298275802947,
+            },
+            3,
+        );
+        pq.push(
+            Person {
+                id: 4,
+                name: "d".to_string(),
+                phone: 65723012057,
+            },
+            4,
+        );
+        pq.push(
+            Person {
+                id: 5,
+                name: "e".to_string(),
+                phone: 7237569870239,
+            },
+            5,
+        );
+        pq.push(
+            Person {
+                id: 6,
+                name: "f".to_string(),
+                phone: 35756872497,
+            },
+            6,
+        );
+        println!("{:?}", pq);
+
+        let (item_max, _) = pq.peek_max_mut().unwrap();
+        item_max.name.push('g');
+
+        let (item_max, priority_max) = pq.pop_max().unwrap();
+        assert_eq!(
+            item_max,
+            Person {
+                id: 6,
+                // name is not used for checking equality
+                name: "f".to_string(),
+                phone: 35756872497
+            }
+        );
+        assert_eq!(6, priority_max);
+        assert_eq!("fg", item_max.name);
+
+        let (item_min, _) = pq.peek_min_mut().unwrap();
+        item_min.name.push('b');
+
+        let (item_min, priority_min) = pq.pop_min().unwrap();
+        assert_eq!(
+            item_min,
+            Person {
+                id: 1,
+                // name is not used for checking equality
+                name: "f".to_string(),
+                phone: 39281048279
+            }
+        );
+        assert_eq!(1, priority_min);
+        assert_eq!("ab", item_min.name);
+
+        println!("{:?}", pq);
+        assert_eq!(pq.len(), 4);
+    }
+
+    #[test]
+    fn get_mut() {
+        use std::hash::{Hash, Hasher};
+
+        #[derive(Debug)]
+        struct Person {
+            id: u32,
+            name: String,
+            phone: u64,
+        }
+
+        impl Hash for Person {
+            fn hash<H: Hasher>(&self, state: &mut H) {
+                self.id.hash(state);
+                self.phone.hash(state);
+            }
+        }
+
+        impl PartialEq for Person {
+            fn eq(&self, other: &Self) -> bool {
+                self.id == other.id && self.phone == other.phone
+            }
+        }
+
+        impl Eq for Person {}
+
+        let mut pq = DoublePriorityQueue::new();
+        assert_eq!(
+            pq.get_mut(&Person {
+                id: 1,
+                name: "a".to_string(),
+                phone: 39281048279,
+            }),
+            None
+        );
+
+        pq.push(
+            Person {
+                id: 1,
+                name: "a".to_string(),
+                phone: 39281048279,
+            },
+            1,
+        );
+        pq.push(
+            Person {
+                id: 2,
+                name: "b".to_string(),
+                phone: 23912750234,
+            },
+            2,
+        );
+        pq.push(
+            Person {
+                id: 3,
+                name: "c".to_string(),
+                phone: 1298275802947,
+            },
+            3,
+        );
+        pq.push(
+            Person {
+                id: 4,
+                name: "d".to_string(),
+                phone: 65723012057,
+            },
+            4,
+        );
+        pq.push(
+            Person {
+                id: 5,
+                name: "e".to_string(),
+                phone: 7237569870239,
+            },
+            5,
+        );
+        pq.push(
+            Person {
+                id: 6,
+                name: "f".to_string(),
+                phone: 35756872497,
+            },
+            6,
+        );
+        println!("{:?}", pq);
+
+        let (item, _) = pq
+            .get_mut(&Person {
+                id: 1,
+                name: "a".to_string(),
+                phone: 39281048279,
+            })
+            .unwrap();
+        item.name.push('g');
+
+        let (item_min, priority_min) = pq.pop_min().unwrap();
+        assert_eq!(
+            item_min,
+            Person {
+                id: 1,
+                // name is not used for checking equality
+                name: "f".to_string(),
+                phone: 39281048279
+            }
+        );
+        assert_eq!(1, priority_min);
+        assert_eq!("ag", item_min.name);
+
+        println!("{:?}", pq);
+        assert_eq!(pq.len(), 5);
+    }
+
     #[test]
     fn push_update() {
         let mut pq = DoublePriorityQueue::new();
@@ -111,6 +409,33 @@ mod doublepq_tests {
         assert_eq!(pq.peek_max(), Some((&"Processor", &6)));
     }
 
+    #[test]
+    fn push_decrease() {
+        let mut pq = DoublePriorityQueue::new();
+        pq.push("Processor", 1);
+        pq.push("Mainboard", 2);
+        pq.push("RAM", 5);
+        pq.push("GPU", 4);
+        pq.push("Disk", 3);
+
+        let processor_priority = |pq: &DoublePriorityQueue<&str, i32>| {
+            *pq.iter()
+                .find_map(|(i, p)| if *i == "Processor" { Some(p) } else { None })
+                .unwrap()
+        };
+
+        pq.push_decrease("SSD", 5);
+        assert_eq!(pq.get("SSD"), Some((&"SSD", &5)));
+
+        pq.push_decrease("Processor", 3);
+        assert_eq!(processor_priority(&pq), 1);
+
+        pq.push_decrease("Processor", 0);
+        assert_eq!(processor_priority(&pq), 0);
+
+        assert_eq!(pq.peek_min(), Some((&"Processor", &0)));
+    }
+
     #[test]
     fn change_priority1() {
         let mut pq = DoublePriorityQueue::new();
@@ -232,6 +557,16 @@ mod doublepq_tests {
         assert_eq!(pq.len(), 2);
     }
 
+    #[test]
+    fn clear() {
+        let v = vec![("a", 1), ("b", 2), ("f", 7)];
+        let mut pq: DoublePriorityQueue<_, _> = DoublePriorityQueue::from(v);
+        assert_eq!(pq.len(), 3);
+
+        pq.clear();
+        assert_eq!(pq.len(), 0);
+    }
+
     #[test]
     fn from_vec_with_repeated() {
         let v = vec![("a", 1), ("b", 2), ("f", 7), ("a", 2)];
@@ -259,6 +594,15 @@ mod doublepq_tests {
         assert_eq!(sorted.as_slice(), &["b", "a", "f"]);
     }
 
+    #[test]
+    fn heap_sort_asc() {
+        type Pq<I, P> = DoublePriorityQueue<I, P>;
+
+        let v = vec![("a", 2), ("b", 7), ("f", 1)];
+        let sorted = (Pq::from(v)).into_ascending_sorted_vec();
+        assert_eq!(sorted.as_slice(), &["f", "a", "b"]);
+    }
+
     #[test]
     fn change_priority_by() {
         use std::iter::FromIterator;
@@ -343,6 +687,68 @@ mod doublepq_tests {
         }
     }
 
+    #[test]
+    fn drain() {
+        use std::collections::hash_map::RandomState;
+        let mut queue = DoublePriorityQueue::<i32, i32, RandomState>::default();
+
+        for i in 0..7 {
+            queue.push(i, i);
+        }
+
+        let previous_capacity = queue.capacity();
+        queue.drain();
+
+        assert_eq!(queue.len(), 0);
+        assert_eq!(queue.capacity(), previous_capacity);
+        assert_eq!(queue.pop_min(), None);
+        assert_eq!(queue.pop_max(), None);
+    }
+
+    #[test]
+    fn reserve() {
+        use std::collections::hash_map::RandomState;
+        let mut queue = DoublePriorityQueue::<i32, i32, RandomState>::default();
+
+        queue.reserve(100);
+
+        assert_eq!(queue.len(), 0);
+        assert!(queue.capacity() >= 100);
+    }
+
+    #[test]
+    fn reserve_exact() {
+        use std::collections::hash_map::RandomState;
+        let mut queue = DoublePriorityQueue::<i32, i32, RandomState>::default();
+
+        queue.reserve_exact(100);
+
+        assert_eq!(queue.len(), 0);
+        assert_eq!(queue.capacity(), 100);
+    }
+
+    #[test]
+    fn try_reserve() {
+        use std::collections::hash_map::RandomState;
+        let mut queue = DoublePriorityQueue::<i32, i32, RandomState>::default();
+
+        queue.try_reserve(100).unwrap();
+
+        assert_eq!(queue.len(), 0);
+        assert!(queue.capacity() >= 100);
+    }
+
+    #[test]
+    fn try_reserve_exact() {
+        use std::collections::hash_map::RandomState;
+        let mut queue = DoublePriorityQueue::<i32, i32, RandomState>::default();
+
+        queue.try_reserve_exact(100).unwrap();
+
+        assert_eq!(queue.len(), 0);
+        assert_eq!(queue.capacity(), 100);
+    }
+
     #[test]
     fn extend() {
         let mut pq = DoublePriorityQueue::new();
@@ -397,12 +803,154 @@ mod doublepq_tests {
         assert_eq!(pq.pop_max(), Some(("b", 20)));
 
         /*
-        As expected, this does not compile
+        // As expected, this does not compile
         let iter_mut = pq.iter_mut();
-        iter_mut.for_each(|(_, p)| {*p += 2});
 
-        assert_eq!(pq.pop_max(), Some(("f", 9)));
-        */
+        assert_eq!(pq.pop_max(), Some(("a", 21)));
+        iter_mut.for_each(|(_, p)| {*p += 2}); */
+    }
+
+    #[test]
+    fn retain() {
+        #[derive(Hash, PartialEq, Eq, Debug)]
+        struct Animal {
+            name: String,
+            can_fly: bool,
+            can_swim: bool,
+        }
+
+        impl Animal {
+            pub fn new(name: String, can_fly: bool, can_swim: bool) -> Self {
+                Animal {
+                    name,
+                    can_fly,
+                    can_swim,
+                }
+            }
+        }
+
+        let mut pq = DoublePriorityQueue::new();
+        pq.push(Animal::new("dog".to_string(), false, true), 1);
+        pq.push(Animal::new("cat".to_string(), false, false), 2);
+        pq.push(Animal::new("bird".to_string(), true, false), 7);
+        pq.push(Animal::new("fish".to_string(), false, true), 4);
+        pq.push(Animal::new("cow".to_string(), false, false), 3);
+        pq.retain(|i, _| i.can_swim);
+
+        assert_eq!(
+            pq.pop_max(),
+            Some((Animal::new("fish".to_string(), false, true), 4))
+        );
+        assert_eq!(
+            pq.pop_max(),
+            Some((Animal::new("dog".to_string(), false, true), 1))
+        );
+    }
+
+    #[test]
+    fn retain_mut() {
+        #[derive(Hash, PartialEq, Eq, Debug)]
+        struct Animal {
+            name: String,
+            can_fly: bool,
+            can_swim: bool,
+        }
+
+        impl Animal {
+            pub fn new(name: String, can_fly: bool, can_swim: bool) -> Self {
+                Animal {
+                    name,
+                    can_fly,
+                    can_swim,
+                }
+            }
+        }
+
+        let mut pq = DoublePriorityQueue::new();
+        pq.push(Animal::new("dog".to_string(), false, true), 1);
+        pq.push(Animal::new("cat".to_string(), false, false), 2);
+        pq.push(Animal::new("bird".to_string(), true, false), 7);
+        pq.push(Animal::new("fish".to_string(), false, true), 4);
+        pq.push(Animal::new("cow".to_string(), false, false), 3);
+
+        pq.retain_mut(|i, p| {
+            *p += 10;
+            i.can_swim
+        });
+
+        assert_eq!(
+            pq.pop_max(),
+            Some((Animal::new("fish".to_string(), false, true), 14))
+        );
+        assert_eq!(
+            pq.pop_max(),
+            Some((Animal::new("dog".to_string(), false, true), 11))
+        );
+    }
+
+    #[test]
+    fn extract_if() {
+        #[derive(Hash, PartialEq, Eq, Debug)]
+        struct Animal {
+            name: String,
+            can_fly: bool,
+            can_swim: bool,
+        }
+
+        impl Animal {
+            pub fn new(name: String, can_fly: bool, can_swim: bool) -> Self {
+                Animal {
+                    name,
+                    can_fly,
+                    can_swim,
+                }
+            }
+        }
+
+        let mut pq = DoublePriorityQueue::new();
+        pq.push(Animal::new("dog".to_string(), false, true), 1);
+        pq.push(Animal::new("cat".to_string(), false, false), 2);
+        pq.push(Animal::new("bird".to_string(), true, false), 7);
+        pq.push(Animal::new("fish".to_string(), false, true), 4);
+        pq.push(Animal::new("cow".to_string(), false, false), 3);
+
+        let swimming_animals: Vec<(Animal, i32)> = pq
+            .extract_if(|i, p| {
+                if i.can_fly {
+                    *p -= 18;
+                    return false;
+                }
+
+                i.can_swim
+            })
+            .collect();
+
+        assert_eq!(
+            swimming_animals,
+            [
+                (Animal::new("dog".to_string(), false, true), 1),
+                (Animal::new("fish".to_string(), false, true), 4)
+            ]
+        );
+        assert_eq!(
+            pq.pop_max(),
+            Some((Animal::new("cow".to_string(), false, false), 3))
+        );
+        assert_eq!(
+            pq.pop_max(),
+            Some((Animal::new("cat".to_string(), false, false), 2))
+        );
+        assert_eq!(
+            pq.pop_max(),
+            Some((Animal::new("bird".to_string(), true, false), -11))
+        );
+
+        /*
+        // As expected, this does not compile
+        let extract_if = pq.extract_if(|i, p| { i.can_fly });
+
+        assert_eq!(pq.pop_max(), None);
+        extract_if.for_each(|(_, p)| println!("{:?}", p)); */
     }
 
     #[test]
