@@ -5,10 +5,12 @@
 
 // mod impls;
 
-use core::marker::PhantomData;
+use core::{fmt, marker::PhantomData};
 
 use rancor::Fallible;
 
+#[doc(inline)]
+pub use crate::niche::niching::DefaultNiche;
 use crate::{Archive, Deserialize, Place, Portable, Serialize};
 
 /// A variant of [`Archive`] that works with wrappers.
@@ -354,6 +356,9 @@ pub struct InlineAsBox;
 /// UTF-8, but they usually are anyway. Using this wrapper will archive them as
 /// if they were regular `String`s.
 ///
+/// It also allows `&str` to be archived like an owned `String`. However, note
+/// that `&str` cannot be *deserialized* this way.
+///
 /// # Example
 ///
 /// ```
@@ -362,11 +367,13 @@ pub struct InlineAsBox;
 /// use rkyv::{with::AsString, Archive};
 ///
 /// #[derive(Archive)]
-/// struct Example {
+/// struct Example<'a> {
 ///     #[rkyv(with = AsString)]
 ///     os_string: OsString,
 ///     #[rkyv(with = AsString)]
 ///     path: PathBuf,
+///     #[rkyv(with = AsString)]
+///     reference: &'a str,
 /// }
 /// ```
 #[derive(Debug)]
@@ -426,6 +433,9 @@ pub struct AsOwned;
 /// `BTreeMap` by serializing the key-value pairs directly instead of building a
 /// data structure in the buffer.
 ///
+/// It also allows `&[T]` to be archived like an owned `Vec`. However, note
+/// that `&[T]` cannot be *deserialized* this way.
+///
 /// # Example
 ///
 /// ```
@@ -434,9 +444,11 @@ pub struct AsOwned;
 /// use rkyv::{with::AsVec, Archive};
 ///
 /// #[derive(Archive)]
-/// struct Example {
+/// struct Example<'a> {
 ///     #[rkyv(with = AsVec)]
 ///     values: HashMap<String, u32>,
+///     #[rkyv(with = AsVec)]
+///     slice: &'a [u32],
 /// }
 /// ```
 #[derive(Debug)]
@@ -473,6 +485,114 @@ pub struct AsVec;
 #[derive(Debug)]
 pub struct Niche;
 
+/// A wrapper that niches based on a generic [`Niching`].
+///
+/// A common type combination is `Option<Box<T>>`. By niching `None` into the
+/// null pointer, the archived version can save some space on-disk.
+///
+/// # Example
+///
+/// ```
+/// use core::mem::size_of;
+///
+/// use rkyv::{
+///     niche::niching::{NaN, Null},
+///     with::NicheInto,
+///     Archive, Archived,
+/// };
+///
+/// #[derive(Archive)]
+/// struct BasicExample {
+///     maybe_box: Option<Box<str>>,
+///     maybe_non_nan: Option<f32>,
+/// }
+///
+/// #[derive(Archive)]
+/// struct NichedExample {
+///     #[rkyv(with = NicheInto<Null>)]
+///     maybe_box: Option<Box<str>>,
+///     #[rkyv(with = NicheInto<NaN>)]
+///     maybe_non_nan: Option<f32>,
+/// }
+///
+/// assert!(
+///     size_of::<Archived<BasicExample>>()
+///         > size_of::<Archived<NichedExample>>()
+/// );
+/// ```
+///
+/// [`Niching`]: crate::niche::niching::Niching
+pub struct NicheInto<N: ?Sized>(PhantomData<N>);
+
+impl<N: ?Sized> Default for NicheInto<N> {
+    fn default() -> Self {
+        Self(PhantomData)
+    }
+}
+
+impl<N: ?Sized> fmt::Debug for NicheInto<N> {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.write_str("NicheInto")
+    }
+}
+
+/// A wrapper that first applies another wrapper `W` to the value inside an
+/// `Option` and then niches the result based on the [`Niching`] `N`.
+///
+/// # Example
+///
+/// ```
+/// use rkyv::{
+///     with::{AsBox, MapNiche},
+///     Archive, Serialize,
+/// };
+///
+/// #[derive(Archive, Serialize)]
+/// struct BasicExample {
+///     option: Option<HugeType>,
+/// }
+///
+/// #[derive(Archive, Serialize)]
+/// struct NichedExample {
+///     #[rkyv(with = MapNiche<AsBox>)]
+///     option: Option<HugeType>,
+/// }
+///
+/// #[derive(Archive, Serialize)]
+/// struct HugeType([u8; 1024]);
+///
+/// # fn main() -> Result<(), rkyv::rancor::Error> {
+/// let basic_value = BasicExample { option: None };
+/// let basic_bytes = rkyv::to_bytes(&basic_value)?;
+/// assert_eq!(basic_bytes.len(), 1 + 1024);
+///
+/// let niched_value = NichedExample { option: None };
+/// let niched_bytes = rkyv::to_bytes(&niched_value)?;
+/// assert_eq!(niched_bytes.len(), 4); // size_of::<ArchivedBox<_>>()
+/// # Ok(()) }
+/// ```
+///
+/// [`Niching`]: crate::niche::niching::Niching
+pub struct MapNiche<W: ?Sized, N: ?Sized = DefaultNiche> {
+    _map: PhantomData<W>,
+    _niching: PhantomData<N>,
+}
+
+impl<W: ?Sized, N: ?Sized> Default for MapNiche<W, N> {
+    fn default() -> Self {
+        Self {
+            _map: PhantomData,
+            _niching: PhantomData,
+        }
+    }
+}
+
+impl<W: ?Sized, N: ?Sized> fmt::Debug for MapNiche<W, N> {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.write_str("MapNiche")
+    }
+}
+
 /// A wrapper that converts a [`SystemTime`](std::time::SystemTime) to a
 /// [`Duration`](std::time::Duration) since
 /// [`UNIX_EPOCH`](std::time::UNIX_EPOCH).
